<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/spip?lang_cible=tr
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// 0
	'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-dev',
	'0_langue' => 'Türkçe [tr]',
	'0_liste' => 'spip-dev@rezo.net',
	'0_mainteneur' => 'admin@inceden.net',

	// A
	'access_interface_graphique' => 'Tam grafik arayüze geri dön',
	'access_mode_texte' => 'Basitleştirilmiş metin arayüzünü göster',
	'admin_debug' => 'hata ayıkla',
	'admin_modifier_article' => 'Bu makaleyi değiştir',
	'admin_modifier_auteur' => 'Bu yazarı değiştir',
	'admin_modifier_breve' => 'Bu kısa haberi değiştir',
	'admin_modifier_mot' => 'Bu anahtar sözcüğü değiştir',
	'admin_modifier_rubrique' => 'Bu bölümü değiştir',
	'admin_recalculer' => 'Bu sayfayı yeniden oluştur',
	'afficher_trad' => 'çevirileri listele',
	'alerte_maj_impossible' => '<b>Dikkat !</b> SQL veri tabanının @version@ sürümüne güncellenmesi imkansız. Sorun veritabanı değiştirme haklarından kaynaklanıyor olabilir, lütfen sitenizi barındıran şirkete başvurunuz.',
	'alerte_modif_info_concourante' => 'DİKKAT: Bu bilgi başka bir yerde değiştirildi. Güncel değer :',
	'analyse_xml' => 'XML analizi',
	'annuler' => 'İptal et',
	'antispam_champ_vide' => 'Lütfen bu alanı boş bırakınız :',
	'articles_recents' => 'En yeni makaleler',
	'avis_archive_incorrect' => 'arşiv dosyası SPIP dosyası değil',
	'avis_archive_invalide' => 'bu arşiv dosyası geçerli değil',
	'avis_attention' => 'DİKKAT !',
	'avis_champ_incorrect_type_objet' => '@type@ tipindeki nesne için @name@ ismi geçersiz',
	'avis_colonne_inexistante' => '@col@ isimli sütun yok',
	'avis_erreur' => 'Hata: aşağıdaki açıklamaya bakınız',
	'avis_erreur_connexion' => 'Bağlantı hatası',
	'avis_erreur_cookie' => 'çerez sorunu',
	'avis_erreur_fonction_contexte' => 'Yazılım hatası. Bu işlev bu biçimde kullanılmamalı.',
	'avis_erreur_mysql' => 'SQL hatası',
	'avis_erreur_sauvegarde' => 'Yedeklemede hata (@type@ @id_objet@) !',
	'avis_erreur_visiteur' => 'Özel alana erişim sorunu',

	// B
	'barre_a_accent_grave' => 'A harfinin üstüne aksan ekle (Türkçede anlamsız)',
	'barre_aide' => 'Sayfa düzenini zenginleştirmek için tipografik kısayolları kullanınız',
	'barre_e_accent_aigu' => 'E harfinin üstüne aksan ekle (Türkçe’de anlamsız)',
	'barre_eo' => 'Türkçe’de anlamsız',
	'barre_eo_maj' => 'Türkçe’de anlamsız',
	'barre_euro' => '€ işaretini girin',
	'barre_gras' => '{{Kalın}} yaz',
	'barre_guillemets' => '« Tırnak » içine al',
	'barre_guillemets_simples' => 'İkinci biçimde tırnak içine al',
	'barre_intertitre' => '{{{Arabaşlık’a}}} dönüştür',
	'barre_italic' => '{Yana yatık (italik)} yaz',
	'barre_lien' => '[Hipermetin bağlantısına->http://...] dönüştür',
	'barre_lien_input' => 'Lütfen bağlantınızın adresini girin (adresi http://www.adresim.com veya bu sitede bulunan bir metnin numarası şeklinde girebilirsiniz).',
	'barre_note' => '[[Sayfa sonu notuna]] dönüştür',
	'barre_paragraphe' => 'Bir paragraf oluştur',
	'barre_quote' => '<quote>Bir iletiden alıntı yap</quote>',
	'bouton_changer' => 'Değiştir',
	'bouton_chercher' => 'Ara',
	'bouton_choisir' => 'Seç',
	'bouton_download' => 'İndir', # MODIF
	'bouton_enregistrer' => 'Kaydet',
	'bouton_radio_desactiver_messagerie_interne' => 'İç iletileri kapat',
	'bouton_radio_envoi_annonces' => 'Yazar duyurularını yolla',
	'bouton_radio_non_envoi_annonces' => 'Duyuruları yollama',
	'bouton_radio_non_envoi_liste_nouveautes' => 'Yenilikler listesini gönderme',
	'bouton_recharger_page' => 'bu sayfayı yeniden yükle',
	'bouton_telecharger' => 'İndir',
	'bouton_upload' => 'İndir', # MODIF
	'bouton_valider' => 'Onayla',

	// C
	'cal_apresmidi' => 'öğleden sonra',
	'cal_jour_entier' => 'tam gün',
	'cal_matin' => 'sabah',
	'cal_par_jour' => 'günlük takvim',
	'cal_par_mois' => 'aylık takvim',
	'cal_par_semaine' => 'haftalık takvim',
	'choix_couleur_interface' => 'renk',
	'choix_interface' => 'arayüz seçimi',
	'colonne' => 'Sütun',
	'confirm_changer_statut' => 'Dikkat, bu elemanın durumunu değiştirmek istediniz. Devam etmek istiyor musunuz ?',
	'correcte' => 'doğru',

	// D
	'date_aujourdhui' => 'bugün',
	'date_avant_jc' => 'İ.Ö.',
	'date_dans' => ' @delai@ içinde',
	'date_de_mois_1' => '@j@ @nommois@',
	'date_de_mois_10' => '@j@ @nommois@',
	'date_de_mois_11' => '@j@ @nommois@',
	'date_de_mois_12' => '@j@ @nommois@',
	'date_de_mois_2' => '@j@ @nommois@',
	'date_de_mois_3' => '@j@ @nommois@',
	'date_de_mois_4' => '@j@ @nommois@',
	'date_de_mois_5' => '@j@ @nommois@',
	'date_de_mois_6' => '@j@ @nommois@',
	'date_de_mois_7' => '@j@ @nommois@',
	'date_de_mois_8' => '@j@ @nommois@',
	'date_de_mois_9' => '@j@ @nommois@',
	'date_demain' => 'yarın',
	'date_fmt_heures_minutes' => '@h@h@m@min',
	'date_fmt_jour_heure' => '@jour@ @heure@',
	'date_fmt_jour_mois' => '@jour@ @nommois@',
	'date_fmt_jour_mois_annee' => '@jour@ @nommois@ @annee@',
	'date_fmt_mois_annee' => '@nommois@ @annee@',
	'date_fmt_nomjour_date' => '@date@ @nomjour@',
	'date_heures' => 'saat ',
	'date_hier' => 'dün',
	'date_il_y_a' => '@delai@ önce',
	'date_jnum1' => '1.',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'Pazar',
	'date_jour_1_abbr' => 'Pzr.',
	'date_jour_1_initiale' => 'g.',
	'date_jour_2' => 'Pazartesi',
	'date_jour_2_abbr' => 'Ptesi.',
	'date_jour_2_initiale' => 'P.',
	'date_jour_3' => 'Salı',
	'date_jour_3_abbr' => 'Salı',
	'date_jour_3_initiale' => 'S.',
	'date_jour_4' => 'Çarşamba',
	'date_jour_4_abbr' => 'Çarş.',
	'date_jour_4_initiale' => 'Ç.',
	'date_jour_5' => 'Perşembe',
	'date_jour_5_abbr' => 'Perş.',
	'date_jour_5_initiale' => 'P.',
	'date_jour_6' => 'Cuma',
	'date_jour_6_abbr' => 'Cuma',
	'date_jour_6_initiale' => 'C.',
	'date_jour_7' => 'Cumartesi',
	'date_jour_7_abbr' => 'Ctesi',
	'date_jour_7_initiale' => 'Ct.',
	'date_jours' => 'gün',
	'date_minutes' => 'dakika',
	'date_mois' => 'ay',
	'date_mois_1' => 'Ocak',
	'date_mois_10' => 'Ekim',
	'date_mois_11' => 'Kasım',
	'date_mois_12' => 'Aralık',
	'date_mois_2' => 'Şubat',
	'date_mois_3' => 'Mart',
	'date_mois_4' => 'Nisan',
	'date_mois_5' => 'Mayıs',
	'date_mois_6' => 'Haziran',
	'date_mois_7' => 'Temmuz',
	'date_mois_8' => 'Ağustos',
	'date_mois_9' => 'Eylül',
	'date_saison_1' => 'kış',
	'date_saison_2' => 'ilkbahar',
	'date_saison_3' => 'yaz',
	'date_saison_4' => 'sonbahar',
	'date_semaines' => 'hafta',
	'dirs_commencer' => ' yüklemeye gerçekten başlamak için',
	'dirs_preliminaire' => 'Ön bilgi : <b>Erişim haklarını ayarlayınız</b>',
	'dirs_probleme_droits' => 'Erişim hakları sorunu ',
	'dirs_repertoires_absents' => '<p><b>Şu dizinler bulunamadı : </b></p><ul>@bad_dirs@</ul> </b>
  <p>Büyük küçük harf hatasına bağlı olabilir.
  Dizinlerin küçük büyük harflerle yazılışlarının yukarıda gösterilenlerle uyuştuğunu kontrol edin;  eğer uyuşmuyorsa FTP programınızla dizin isimlerini düzeltin.</p>
  <p>Bu işlemi yaptığınızda ',
	'dirs_repertoires_suivants' => '<p><b>Aşağıdaki dizinlere yazma izni yoktur : </b></p><ul>@bad_dirs@.</ul> 
  <p>Bu sorunu çözmek için FTP programınızla her bir dizine erişim haklarını düzenleyin. Bu yordam, kurulum kitapçığında detaylı biçimde açıklanmıştır./p> 
  <p>Bu işlemi yaptığınızda ',
	'double_occurrence' => 'Çift tekrar ', # MODIF

	// E
	'en_cours' => 'işlenmekte',
	'envoi_via_le_site' => 'Site üzerinden gönder',
	'erreur' => 'Hata',
	'erreur_balise_non_fermee' => 'son etiket kapatılmamış :',
	'erreur_texte' => 'hata(lar)',
	'etape' => 'Aşama',

	// F
	'fichier_introuvable' => '@fichier@ dosyası bulunamadı',
	'form_deja_inscrit' => 'Zaten kayıtlısınız.',
	'form_email_non_valide' => 'E-posta adresiniz geçersiz.',
	'form_forum_access_refuse' => 'Artık bu siteye erişim izniniz yok.',
	'form_forum_bonjour' => 'Merhaba @nom@,',
	'form_forum_email_deja_enregistre' => 'Bu e-posta adresi zaten kayıtlı, kullanmakta olduğunuz şifrenizi kullanmaya devam edebilirsiniz.',
	'form_forum_identifiant_mail' => 'Yeni tanımlayıcınız e-posta yoluyla gönderildi.',
	'form_forum_identifiants' => 'Kişisel tanımlayıcılar',
	'form_forum_indiquer_nom_email' => 'Buraya isminizi ve e-posta adresinizi giriniz. Yeni tanımlayıcınız size bir e-posta ile hemen gönderilecektir.',
	'form_forum_login' => 'kullanıcı ismi :',
	'form_forum_message_auto' => '(bu otomatik bir iletidir)',
	'form_forum_pass' => 'şifre :',
	'form_forum_probleme_mail' => 'E-posta sorunu : tanımlayıcı gönderilemiyor.',
	'form_forum_voici1' => '"@nom_site_spip@" (@adresse_site@) site yaşamına katılabilmek için tanımlayıcılarınız :',
	'form_forum_voici2' => '"@nom_site_spip@" (@adresse_login@) sitesinde makale yayınlayabilmeniz için gereken kimlik bilgileriniz :',
	'form_indiquer_email' => 'Lütfen e-posta adresinizi belirtiniz.',
	'form_indiquer_nom' => 'Lütfen isminizi belirtiniz.',
	'form_indiquer_nom_site' => 'Lütfen sitenizin ismini belirtiniz.',
	'form_pet_deja_enregistre' => 'Bu site zaten kayıtlı',
	'form_pet_signature_pasprise' => 'İmzanız dikkate alınmadı.',
	'form_prop_confirmer_envoi' => 'Gönderiyi onayla',
	'form_prop_description' => 'Tanım / Yorum',
	'form_prop_enregistre' => 'Öneriniz kaydedildi, sitenin sorumluları tarafından onaylandıktan sonra çevrimiçi yayınlanacak.',
	'form_prop_envoyer' => 'Bir ileti gönder',
	'form_prop_indiquer_email' => 'Lütfen geçerli bir e-posta adresi belirtiniz',
	'form_prop_indiquer_nom_site' => 'Sitenin ismini giriniz.',
	'form_prop_indiquer_sujet' => 'Bir konu belirtiniz',
	'form_prop_message_envoye' => 'İleti gönderildi',
	'form_prop_non_enregistre' => 'Öneriniz kaydedilmedi.',
	'form_prop_sujet' => 'Konu',
	'form_prop_url_site' => 'Sitenin Url adresi', # MODIF
	'forum_non_inscrit' => 'Kayıtlı değilsiniz veya adresiniz veya şifreniz hatalı.',
	'forum_par_auteur' => 'yazan @auteur@ ',
	'forum_titre_erreur' => 'Hata...',

	// I
	'ical_texte_rss_articles' => 'Makalelerin «backend» dosyası şu adrestedir:',
	'ical_texte_rss_articles2' => 'Sitenin her bir bölümünün makaleleri için «backend» dosyaları edinebilirsiniz :',
	'ical_texte_rss_breves' => 'Ayrıca site haberlerini içeren bir dosya mevcuttur. Bir bölüm numarası belirterek, sadece bu bölümün haberlerini elde edebilirsiniz.',
	'icone_a_suivre' => 'İzlenecek',
	'icone_admin_site' => 'Site yönetimi',
	'icone_agenda' => 'Ajanda',
	'icone_aide_ligne' => 'Yardım',
	'icone_articles' => 'Makaleler',
	'icone_auteurs' => 'Yazarlar',
	'icone_brouteur' => 'Hızlı gezinti',
	'icone_configuration_site' => 'Yapılandırma',
	'icone_configurer_site' => 'Sitenizi yapılandırın',
	'icone_creer_nouvel_auteur' => 'Yeni bir yazar oluştur',
	'icone_creer_rubrique' => 'Bölüm oluştur',
	'icone_creer_sous_rubrique' => 'Alt-bölüm oluştur',
	'icone_deconnecter' => 'Çıkış',
	'icone_discussions' => 'Tartışmalar',
	'icone_doc_rubrique' => 'Bölüm belgeleri',
	'icone_ecrire_article' => 'Yeni bir makale yaz',
	'icone_edition_site' => 'Yayın',
	'icone_gestion_langues' => 'Dillerin yönetimi',
	'icone_informations_personnelles' => 'Kişisel bilgiler',
	'icone_interface_complet' => 'Tüm arayüz',
	'icone_interface_simple' => 'Basit arayüz',
	'icone_maintenance_site' => 'Site bakımı',
	'icone_messagerie_personnelle' => 'Kişisel iletiler',
	'icone_repartition_debut' => 'Dağılımı en başından itibaren göster',
	'icone_rubriques' => 'Bölümler',
	'icone_sauver_site' => 'Siteyi yedekle',
	'icone_site_entier' => 'Tüm site',
	'icone_sites_references' => 'Önerilen siteler',
	'icone_statistiques' => 'Site istatistikleri',
	'icone_suivi_activite' => 'Site yaşamını izle',
	'icone_suivi_actualite' => 'Site gelişimi',
	'icone_suivi_pettions' => 'Dilekçeleri izle / Yönet',
	'icone_suivi_revisions' => 'Makale değişiklikleri',
	'icone_supprimer_document' => 'Bu belgeyi sil',
	'icone_supprimer_image' => 'Bu resmi sil',
	'icone_tous_articles' => 'Tüm makaleleriniz',
	'icone_tous_auteur' => 'Tüm yazarlar',
	'icone_visiter_site' => 'Ziyaret et', # MODIF
	'icone_voir_en_ligne' => 'Çevrimiçi göster',
	'img_indisponible' => 'resim mevcut değil',
	'impossible' => 'olanaksız',
	'info_a_suivre' => 'İZLENECEK »',
	'info_acces_interdit' => 'Erişim yasak',
	'info_acces_refuse' => 'Erişim reddedildi',
	'info_action' => 'Eylem : @action@',
	'info_administrer_rubriques' => 'Bu bölümü ve alt-bölümleri yönetebilirsiniz',
	'info_adresse_non_indiquee' => 'Denenecek bir adres belirtmediniz !',
	'info_aide' => 'YARDIM :',
	'info_ajouter_mot' => 'Bu sözcüğü ekle',
	'info_annonce' => 'DUYURU',
	'info_annonces_generales' => 'Genel duyurular :',
	'info_article_propose' => 'Önerilen makale',
	'info_article_publie' => 'Yayınlanan makale',
	'info_article_redaction' => 'Yazılmakta olan makale',
	'info_article_refuse' => 'Reddedilen makale',
	'info_article_supprime' => 'Silinen makale',
	'info_articles' => 'Makaleler',
	'info_articles_a_valider' => 'Onaylanacak makaleler',
	'info_articles_proposes' => 'Önerilen makaleler',
	'info_auteurs_nombre' => 'yazar(lar) :',
	'info_authentification_ftp' => 'Onay (FTP ile)',
	'info_breves_2' => 'kısa haberler',
	'info_connexion_refusee' => 'Bağlantı reddedildi',
	'info_contact_developpeur' => 'Lütfen bir program geliştirici ile temasa geçiniz.',
	'info_contenance' => 'Site içeriği :',
	'info_contribution' => 'Forum katkıları', # MODIF
	'info_copyright' => '@spip@, @lien_gpl@ GPL lisansı ile dağıtılan serbest bir yazılımdır.',
	'info_copyright_doc' => 'Ayrıntılı bilgi için, bkz.  <a href="@spipnet@">http://www.spip.net/fr</a>.', # MODIF
	'info_copyright_gpl' => 'GPL lisansı altında',
	'info_cours_edition' => 'Yazılmakta olan makaleleriniz',
	'info_creer_repertoire' => 'Şu isimde bir dosya veya dizin oluşturunuz :',
	'info_creer_repertoire_2' => '<b>@repertoire@</b> alt-dizini içerisinde, daha sonra :',
	'info_creer_vignette' => 'otomatik ikon oluşturma',
	'info_deplier' => 'Açılıp sergilenmesi',
	'info_descriptif_nombre' => 'tanımlayıcı(lar) :',
	'info_description' => 'Tanımlama :',
	'info_description_2' => 'Tanımlama :',
	'info_dimension' => 'Boyutlar :',
	'info_ecire_message_prive' => 'Özel bir ileti yaz',
	'info_email_invalide' => 'Geçersiz e-posta adresi.',
	'info_en_cours_validation' => 'Yazılmakta olan makaleleriniz',
	'info_en_ligne' => 'Şu anda çevrimiçi :',
	'info_envoyer_message_prive' => 'Bu yazara özel bir ileti gönder',
	'info_erreur_requete' => 'Aramada hata :',
	'info_erreur_squelette2' => 'Hiçbir @fichier@ iskeleti müsait değil...',
	'info_erreur_systeme' => 'Sistem hatası (hata no @errsys@)',
	'info_erreur_systeme2' => 'Sabit disk dolu olabilir veya veritabanı hasar görmüş olabilir.<br />
<span style="color:red;">Veritabanını <a href=\'@script@\'>onarmayı deneyiniz </a>, veya sitenizi barındıran firmayı arayınız.</span>',
	'info_fini' => 'Bitti !',
	'info_format_image' => 'İkon yaratmak için kullanılabilecek resim formatları : @gd_formats@.',
	'info_format_non_defini' => 'tanımsız format',
	'info_grand_ecran' => 'Büyük ekran',
	'info_image_aide' => 'YARDIM',
	'info_image_process_titre' => 'İkon oluşturma yöntemleri',
	'info_impossible_lire_page' => '<b>Hata !</b> Sayfa vekil (proxy) üzerinden <tt><html>@test_proxy@</html></tt> okunamıyor  <tt>',
	'info_installation_systeme_publication' => 'Yayın sistemi kurulumu...',
	'info_installer_documents' => '@upload@ dizininde bulunan tüm belgeleri otomatik olarak kurabilirsiniz. ',
	'info_installer_ftp' => 'Yönetici olarak (FTP ile) @upload@ dizinine dosya gönderip sonra onları buradan direkt olarak seçebilirsiniz. ',
	'info_installer_images' => 'JPEG, GIF ve PNG formatında resimler yükleyebilirsiniz.',
	'info_installer_images_dossier' => 'Buradan seçim yapabilmek için @upload@ dizinine resim yükleyiniz. ',
	'info_interface_complete' => 'Tam arayüz',
	'info_interface_simple' => 'Basit arayüz',
	'info_joindre_document_article' => 'Bu makaleye ekleyebileceğiniz belgeler ',
	'info_joindre_document_rubrique' => 'Bu bölüme ekleyebileceğiniz belgeler ',
	'info_joindre_documents_article' => 'Makalenize ekleyebileceğiniz belgeler :',
	'info_l_article' => 'makale',
	'info_la_breve' => 'kısa haber',
	'info_la_rubrique' => 'bölüm',
	'info_langue_principale' => 'Sitenin ana dili',
	'info_largeur_vignette' => '@largeur_vignette@ x @hauteur_vignette@ piksel',
	'info_les_auteurs_1' => 'yazan @les_auteurs@ ',
	'info_logo_format_interdit' => 'Sadece @formats@ formatındaki logolar kullanılabilir.',
	'info_logo_max_poids' => 'Logolar @maxi@ dan daha küçük olmalıdır (bu dosyanın boyutu  @actuel@).',
	'info_mail_fournisseur' => 'isminiz@hizmet_veren_firma.com',
	'info_message_2' => 'İLETİ',
	'info_message_supprime' => 'İLETİ SİLİNDİ',
	'info_mise_en_ligne' => 'Çevrimiçi yayın tarihi :',
	'info_modification_parametres_securite' => 'güvenlik parametreleri değişikliği',
	'info_mois_courant' => 'Ay içinde :',
	'info_mot_cle_ajoute' => 'Şu anahtar sözcük eklendi > ',
	'info_multi_herit' => 'Varsayılan dil :',
	'info_multi_langues_soulignees' => '<u>Altı çizili dillerin</u> arayüzde tüm metinlerin çevirileri bulunmaktadır. Bu dilleri seçerseniz, kamu sitesinin bir çok elemanı (tarihler, formlar) otomatik olarak çevrilecektir. Altı çizili olmayan diller için ise bu elemanlar sitenin başlıca dilinde görüntülenecektir.', # MODIF
	'info_multilinguisme' => 'Çok dillilik',
	'info_nom_non_utilisateurs_connectes' => 'Bağlı kullanıcılar listesinde isminiz görünmüyor.',
	'info_nom_utilisateurs_connectes' => 'Bağlı kullanıcılar listesinde isminiz görünüyor.',
	'info_nombre_en_ligne' => 'Şu anda çevrimiçi :',
	'info_non_resultat' => '"@cherche_mot@" için hiç sonuç yok',
	'info_non_utilisation_messagerie' => 'Bu sitenin iç ileti sistemini kullanmıyorsunuz.',
	'info_nouveau_message' => 'YENİ BİR İLETİNİZ VAR',
	'info_nouveaux_messages' => '@total_messages@ YENİ MESAJINIZ VAR',
	'info_numero_abbreviation' => 'N° ',
	'info_obligatoire' => 'Bu bilgi zorunludur.',
	'info_pense_bete' => 'HATIRLATMA',
	'info_petit_ecran' => 'Küçük ekran',
	'info_petition_close' => 'Dilekçe kapandı',
	'info_pixels' => 'Piksel',
	'info_plusieurs_mots_trouves' => ' "@cherche_mot@" için birçok anahtar sözcük bulundu',
	'info_portfolio_automatique' => 'Otomatik portföy :',
	'info_premier_resultat' => '[Toplam @total@ dan @debut_limit@ ilk sonuç]',
	'info_premier_resultat_sur' => '[@debut_limit@ ilk sonuç / @total@ sonuç]',
	'info_propose_1' => '[@nom_site_spip@] Öneriyor : @titre@',
	'info_propose_2' => 'Önerilen makale
---------------',
	'info_propose_3' => '"@titre@" makalesi yayınlanmak üzere önerildi.',
	'info_propose_4' => 'Lütfen inceleyiniz ve görüşünüzü belirtiniz',
	'info_propose_5' => 'bağlı olan forumda. Forumun adresi:',
	'info_publie_01' => '"@titre@" makalesi @connect_nom@ tarafından onaylandı.',
	'info_publie_1' => '[@nom_site_spip@] YAYINLANDI : @titre@',
	'info_publie_2' => 'Yayınlanan makale
-----------------',
	'info_rechercher' => 'Ara',
	'info_rechercher_02' => 'Ara :',
	'info_remplacer_vignette' => 'Varsayılan etiketi kişiselleştirilmiş bir logo ile değiştir :',
	'info_sans_titre_2' => 'başlıksız',
	'info_selectionner_fichier' => '@upload@ dizininden bir dosya seçebilirsiniz. ',
	'info_selectionner_fichier_2' => 'Bir dosya seç :',
	'info_supprimer_vignette' => 'Bu etiketi sil',
	'info_symbole_bleu' => '<b>Mavi</b> sembol bir <b>hatırlatmayı</b> gösterir : yani, kişisel kullanımınız için bir iletidir.',
	'info_symbole_jaune' => '<b>Sarı</b> sembol <b>tüm editörlere yönelik</b> bir duyuruyu gösterir : tüm yöneticiler tarafından değiştirilebilir ve tüm editörler tarafından görülebilir. ',
	'info_symbole_vert' => 'Sarı sembol sitenin başka kullanıcılarıyla yapılan ileti alışverişlerini gösterir.',
	'info_telecharger_nouveau_logo' => 'Yeni bir logo yükle :',
	'info_telecharger_ordinateur' => 'Bilgisayarınızdan indiriniz :',
	'info_tous_resultats_enregistres' => '[tüm sonuçlar kaydedildi]',
	'info_tout_afficher' => 'Tümünü görüntüle',
	'info_travaux_texte' => 'Bu site henüz konfigüre edilmedi. Lütfen daha sonra uğrayınız.',
	'info_travaux_titre' => 'Site yapım aşamasında.',
	'info_trop_resultat' => ' "@cherche_mot@" için çok fazla sonuç çıktı; lütfen aramayı netleştirin.',
	'info_utilisation_messagerie_interne' => 'Bu sitenin iç ileti sistemini kullanıyorsunuz.',
	'info_valider_lien' => 'Bu bağlantıyı onayla',
	'info_verifier_image' => 'Resimlerinizin doğru iletildiğinden emin olunuz.',
	'info_vignette_defaut' => 'Varsayılan ikon',
	'info_vignette_personnalisee' => 'Kişiselleştirilmiş etiket',
	'info_visite' => 'Ziyaret :',
	'info_vos_rendez_vous' => 'İlerideki randevularınız',
	'infos_vos_pense_bete' => 'Hatırlatmalarınız', # MODIF

	// L
	'lien_afficher_icones_seuls' => 'Sadece ikonları görüntüle',
	'lien_afficher_texte_icones' => 'ikonları ve metni görüntüle',
	'lien_afficher_texte_seul' => 'Sadece metni görüntüle',
	'lien_liberer' => 'Serbest bırak',
	'lien_liberer_tous' => 'Bu makaleleri serbest bırak', # MODIF
	'lien_nouvea_pense_bete' => 'YENİ HATIRLATMA',
	'lien_nouveau_message' => 'YENİ İLETİ',
	'lien_nouvelle_annonce' => 'YENİ DUYURU',
	'lien_petitions' => 'DİLEKÇE ',
	'lien_popularite' => 'Popülerlik : @popularite@%',
	'lien_racine_site' => 'SİTENİN KÖK DİZİNİ',
	'lien_reessayer' => 'Tekrar dene',
	'lien_repondre_message' => 'Bu iletiye yanıt ver',
	'lien_supprimer' => 'Sil',
	'lien_tout_afficher' => 'Tümünü görüntüle',
	'lien_visite_site' => 'Bu siteyi ziyaret et',
	'lien_visites' => '@visites@ ziyaret',
	'lien_voir_auteur' => 'Bu yazarı görüntüle',
	'ligne' => 'Satır',
	'login' => 'Bağlantı',
	'login_acces_prive' => 'Özel alana erişim',
	'login_autre_identifiant' => 'Başka bir kullanıcı ismi ile bağlan',
	'login_cookie_accepte' => 'Lütfen gezgininizi (en azından bu site için) bunları kabul edecek biçimde ayarlayınız.',
	'login_cookie_oblige' => 'Kendinizi güvenli bir şekilde tanımlamak için çerezleri kabul etmelisiniz.',
	'login_deconnexion_ok' => 'Bağlantıya son verildi.',
	'login_erreur_pass' => 'Şifre hatası.',
	'login_espace_prive' => 'Özel alan',
	'login_identifiant_inconnu' => '"@login@" kullanıcı ismi tanınmıyor.',
	'login_login' => 'Kullanıcı ismi :',
	'login_login2' => 'Kullanıcı ismi :', # MODIF
	'login_login_pass_incorrect' => '(Kullanıcı ismi veya şifre hatalı.)',
	'login_motpasseoublie' => 'Şifreyi unuttum',
	'login_non_securise' => 'Dikkat, bu form güvenli değil.
          Eğer şifrenizin ağ üzerinde tesbit edilmesini istemiyorsanız,
          lütfen gezgininizde Javascript’i çalıştırınız ve ',
	'login_nouvelle_tentative' => 'Yeni deneme',
	'login_par_ici' => 'Kayıt oldunuz... buradan devam ediniz...',
	'login_pass2' => 'Şifre :',
	'login_preferez_refuser' => '<b>Eğer çerezleri reddetmeyi tercih ediyorsanız,</b>   başka (daha az güvenli) bir bağlantı yöntemi emrinizde :',
	'login_recharger' => 'sayfayı tekrar yükle',
	'login_rester_identifie' => 'Bir kaç gün tanımlanmış olarak kalayım',
	'login_retour_public' => 'Kamusal siteye dön',
	'login_retour_site' => 'Kamusal siteye dön',
	'login_retoursitepublic' => 'Kamusal siteye dön',
	'login_sinscrire' => 'Kayıt ol',
	'login_test_navigateur' => 'Gezgini dene / Tekrar bağlan',
	'login_verifiez_navigateur' => '(Ancak gezginin şifrenizi belleğe almadığından emin olunuz...)',

	// M
	'masquer_colonne' => 'Bu sütunu sakla',
	'masquer_trad' => 'çevirileri gizle',
	'module_fichiers_langues' => 'Dil dosyaları',

	// N
	'navigateur_pas_redirige' => 'Gezgininiz yeniden yönlenmiyorsa, devam etmek için buraya tıklayınız.',
	'numero' => 'Numara',

	// O
	'occurence' => 'Tekrarlanış',
	'onglet_affacer_base' => 'Veritabanını sil',
	'onglet_auteur' => 'Yazar',
	'onglet_contenu_site' => 'Sitenin içeriği',
	'onglet_evolution_visite_mod' => 'Ziyaretlerin gelişimi',
	'onglet_fonctions_avances' => 'Gelişmiş işlevler',
	'onglet_informations_personnelles' => 'Kişisel bilgi',
	'onglet_interactivite' => 'Etkileşim özelliği',
	'onglet_messagerie' => 'İleti sistemi',
	'onglet_repartition_rubrique' => 'Bölümlere göre dağılım',
	'onglet_save_restaur_base' => 'Veritabanını yedekle / Geri yükle',
	'onglet_vider_cache' => 'Önbelleği boşalt',

	// P
	'pass_choix_pass' => 'Lütfen yeni şifrenizi seçiniz :',
	'pass_erreur' => 'Hata',
	'pass_erreur_acces_refuse' => '<b>Hata : </b> artık bu siteye erişiminiz yoktur.',
	'pass_erreur_code_inconnu' => 'Hata : bu şifre bu siteye erişimi olan hiç bir ziyaretçiye uymuyor.',
	'pass_erreur_non_enregistre' => 'Hata : @email_oubli@ adresi bu siteye kayıtlı değil. ',
	'pass_erreur_non_valide' => 'Hata :  @email_oubli@ e-posta adresi geçerli değil !',
	'pass_erreur_probleme_technique' => 'Hata : teknik bir sorundan ötürü e-posta gönderilemiyor.',
	'pass_espace_prive_bla' => 'Bu sitenin özel alanı,
    kayıtlı ziyaretçilere açıktır. Kayıt olduktan sonra,
    yazılmakta olan makalelere bakabilir, makale önerebilir 
  ve tüm forumlara katılabilirsiniz. ',
	'pass_forum_bla' => 'Kayıtlı ziyaretçilere ayrılmış bir foruma
     müdahale etmek istediniz. ',
	'pass_indiquez_cidessous' => 'Daha önce kayıt olduğunuz e-posta adresinizi aşağıya belirtiniz.
  Tekrar erişebilmek için gereken işlemi 
  belirten 
  bir e-posta alacaksınız. ',
	'pass_mail_passcookie' => '(Bu otomatik bir iletidir)

  @nom_site_spip@ (@adresse_site@)

 sitesine tekrar erişebilmek için 
 lütfen şu adrese gidiniz :

 @sendcookie@
 O zaman yeni bir şifre girebilecek
 ve tekrar siteye bağlanabileceksiniz.  ',
	'pass_mot_oublie' => 'Şifreyi unuttum',
	'pass_nouveau_enregistre' => 'Yeni şifreniz kaydedildi.',
	'pass_nouveau_pass' => 'Yeni şifre',
	'pass_ok' => 'OK',
	'pass_oubli_mot' => 'Şifremi unuttum',
	'pass_quitter_fenetre' => 'Bu pencereyi terk et',
	'pass_rappel_login' => 'Hatırlatma : kullanıcı isminiz « @login@ » dır.',
	'pass_recevoir_mail' => 'Siteye erişiminizi yeniden nasıl kazanabileceğinizi belirten bir e-posta alacaksınız. ',
	'pass_retour_public' => 'Kamu sitesine dönüş',
	'pass_rien_a_faire_ici' => 'Burada yapılacak bir şey yok.',
	'pass_vousinscrire' => 'Bu siteye kaydolmanız',
	'precedent' => 'önceki',
	'previsualisation' => 'Öngörüntüle',
	'previsualiser' => 'Öngörüntüle',

	// R
	'retour' => 'Geri dön',

	// S
	'spip_conforme_dtd' => 'SPIP bu belgeyi DOCTYPE’e uygun buluyor :',
	'squelette' => 'iskelet',
	'squelette_inclus_ligne' => 'iskelet eklendi, satır',
	'squelette_ligne' => 'iskelet, satır',
	'stats_visites_et_popularite' => '@visites@ ziyaret; popülerlik : @popularite@',
	'suivant' => 'sonraki',

	// T
	'taille_ko' => '@taille@ kb',
	'taille_mo' => '@taille@ Mb',
	'taille_octets' => '@taille@ bayt',
	'texte_actualite_site_1' => 'Arayüze alışınca «',
	'texte_actualite_site_2' => 'Tüm arayüz',
	'texte_actualite_site_3' => '»’e tıklayarak daha fazla seçeneğe ulaşabilirsiniz.',
	'texte_creation_automatique_vignette' => 'Bu sitede öngörüntüleme ikonlarının otomatik olarak yaratılması işlemi etkinleştirişmiştir. Eğer bu formdan hareket ederek @gd_formats@, formatlı resimler yüklerseniz, bunlara, en fazla @taille_preview@ piksel boyutunda bir ikon eşlik edecektir.',
	'texte_documents_associes' => 'Aşağıdaki belgeler makale ile bağlantılı olup,
    doğrudan makalenin içine dahil edilmemiştir. Kamu sitesinin sayfa düzenine göre,
    sonradan belge eki olarak görülebilir.',
	'texte_erreur_mise_niveau_base' => 'Güncelleme sırasında veritabanı hatası. @fichier@ resmi ulaşmadı (@id_article@ makalesi). Bu referansı kaydedip güncelemeyi tekrar deneyiniz ve resimlerin makalelerde görüldüğünden emin olunuz. ',
	'texte_erreur_visiteur' => 'Özel alana, girişe izin vermeyen bir kullanıcı ismiyle erişmeyi denediniz.',
	'texte_inc_auth_1' => '<b>@auth_login@</b> kullanıcı ismini girdiniz ancak veritabanında bu kullanıcı ismi yok/artık yok. Lütfen şunu deneyiniz',
	'texte_inc_auth_2' => 'gezgininizi kapatıp tekrar çalıştırınız ve ',
	'texte_inc_auth_3' => 'tekrar bağlanınız.',
	'texte_inc_config' => 'Bu sayfalarda yapılan değişiklikler sitenizin işleyişi üzerinde büyük ölçüde etkilidir. SPIP sisteminin işleyişine aşina olmadığınız sürece müdahale etmemenizi öneririz.  <br /><br /><b>Daha genel bir ifadeyle söylemek gerekirse bu sayfalarla ilgilenme işini sitenin Ağ Yöneticisi’ne bırakmanızı özellikle öneririz.</b>',
	'texte_inc_meta_1' => 'Sistem <code>@fichier@</code> dosyasının yazılması sırasında bir hata ile karşılaştı. Lütfen, site yöneticisi olarak ',
	'texte_inc_meta_2' => '(<code>ecrire/data/</code> dizinindeki) ',
	'texte_inc_meta_3' => '<code>@repertoire@</code> dizinindeki yazma haklarını kontrol ediniz. ',
	'texte_statut_en_cours_redaction' => 'Yazılıyor',
	'texte_statut_poubelle' => 'Çöpe atıldı',
	'texte_statut_propose_evaluation' => 'Değerlendirmeye alındı',
	'texte_statut_publie' => 'Çevrimiçi yayınlandı',
	'texte_statut_refuse' => 'Reddedildi',
	'titre_ajouter_mot_cle' => 'BİR ANAHTAR-SÖZCÜK EKLE :',
	'titre_cadre_raccourcis' => 'KISA YOLLAR :',
	'titre_changer_couleur_interface' => 'Arayüz rengini değiştir',
	'titre_image_admin_article' => 'Bu makaleyi yönetebilirsiniz',
	'titre_image_administrateur' => 'Yönetici',
	'titre_image_aide' => 'Bu eleman hakkında yardım',
	'titre_image_auteur_supprime' => 'Silinmiş yazar',
	'titre_image_redacteur' => 'Erişim hakkı olmayan yazar',
	'titre_image_redacteur_02' => 'Yazar',
	'titre_image_visiteur' => 'Ziyaretçi',
	'titre_joindre_document' => 'BİR BELGE EKLE',
	'titre_mots_cles' => 'ANAHTAR SÖZCÜKLER',
	'titre_probleme_technique' => 'Dikkat : teknik bir sorun (SQL hizmet birimi) sitenin bu bölümüne erişimi engelliyor. Anlayışınız için teşekkürler.',
	'titre_publier_document' => 'BU BÖLÜM ALTINDA BİR BELGE YAYINLA',
	'titre_signatures_attente' => 'Onay bekleyen imzalar',
	'titre_signatures_confirmees' => 'Onaylanmış imzalar',
	'titre_statistiques' => 'Site istatistikleri',
	'titre_titre_document' => 'Belge başlığı :',
	'todo' => 'gelecek',
	'trad_reference' => '(referans makale)', # MODIF

	// Z
	'zbug_balise_b_aval' => ' : B etiketinde sorun var',
	'zbug_balise_inexistante' => 'hata @from@: #@balise@ komutu mevcut değil', # MODIF
	'zbug_balise_sans_argument' => '@balise@ komutunda argüman eksik',
	'zbug_boucle' => 'döngü',
	'zbug_boucle_recursive_undef' => 'tanımsız tekrarlı döngü', # MODIF
	'zbug_calcul' => 'hesaplama',
	'zbug_champ_hors_boucle' => '@champ@ alanı döngü dışında',
	'zbug_champ_hors_motif' => '@champ@ alanı @motif@ döngüsü dışında ', # MODIF
	'zbug_code' => 'kod',
	'zbug_critere_inconnu' => 'tanımsız kriter @critere@', # MODIF
	'zbug_distant_interdit' => 'yasaklanmış dış veri dosyası', # MODIF
	'zbug_doublon_table_sans_cle_primaire' => 'endekssiz bir tabloda tekrarlar var', # MODIF
	'zbug_doublon_table_sans_index' => 'endekslenmemiş bir tabloda tekrarlanan bilgiler', # MODIF
	'zbug_erreur_boucle_double' => 'DÖNGÜ@id@: çift tanımlı', # MODIF
	'zbug_erreur_boucle_fermant' => 'DÖNGÜ@id@: kapatma etiketi eksik', # MODIF
	'zbug_erreur_boucle_syntaxe' => 'Döngü tümcesi hatalı', # MODIF
	'zbug_erreur_compilation' => 'derleme hatası',
	'zbug_erreur_execution_page' => 'sayfa işletilirken hata oluştu', # MODIF
	'zbug_erreur_filtre' => 'Hata : <b>« @filtre@ »</b> filtresi tanımsız', # MODIF
	'zbug_erreur_meme_parent' => '{meme_parent} sadece (FORUMS) veya  (RUBRIQUES) için uygulanabilir', # MODIF
	'zbug_erreur_squelette' => 'İskelette hata var',
	'zbug_hors_compilation' => 'Derleme Dışı',
	'zbug_info_erreur_squelette' => 'Sitede hata var',
	'zbug_inversion_ordre_inexistant' => 'olmayan bir sıralama ters çevrilemez', # MODIF
	'zbug_pagination_sans_critere' => 'kritersiz veya kendini çağıran döngüde kullanılan #PAGINATION {pagination} ', # MODIF
	'zbug_parametres_inclus_incorrects' => 'Ekleme parametreleri hatalı', # MODIF
	'zbug_profile' => 'Hesaplama süresi : @time@',
	'zbug_resultat' => 'sonuç',
	'zbug_serveur_indefini' => 'SQL hizmet birimi tanımsız', # MODIF
	'zbug_statistiques' => 'Süreye göre sınıflanmış SQL istekleri istatistikleri',
	'zbug_table_inconnue' => '« @table@ » SQL tablosu tanımsız',
	'zxml_connus_attributs' => 'bilinen öznitelikler',
	'zxml_de' => 'nın / nin',
	'zxml_inconnu_attribut' => 'bilinmeyen öznitelik',
	'zxml_inconnu_balise' => 'bilinmeyen etiket',
	'zxml_inconnu_entite' => 'bilinmeyen madde',
	'zxml_inconnu_id' => 'bilinmeyen ID',
	'zxml_mais_de' => 'ama nın / nin',
	'zxml_non_conforme' => 'amaca uygun değil',
	'zxml_non_fils' => 'bir alt maddesi değil',
	'zxml_nonvide_balise' => 'boş olmayan etiket',
	'zxml_obligatoire_attribut' => 'zorunlu ama belirtilmemiş etiket',
	'zxml_succession_fils_incorrecte' => 'alt maddelerin peşpeşe gelmesi hatalı',
	'zxml_survoler' => 'doğruları görmek için üzerindne geçmek ???',
	'zxml_valeur_attribut' => 'özniteliğin değeri',
	'zxml_vide_balise' => 'boş etiket',
	'zxml_vu' => 'önceden görülen'
);

?>
